#! /usr/local/bin/python2.1
from M2Crypto import SSL, Err, X509
from socket import *
import getopt
import sys, time

DELIM = "/"
host = ""

#CONFIGURABLE
key    = "key.pem"
cert   = "nettest.pem"
CAFile = "CA.pem"

NETTEST_PORT = 5554
    
def client_send_test( server, test_message ):
    ctx = SSL.Context()
    ctx.load_verify_info(CAFile)
    ctx.load_cert(cert,key)
 
    verify=SSL.verify_peer | SSL.verify_fail_if_no_peer_cert
    depth = 10
    ctx.set_verify(verify, depth)
    s = socket(AF_INET, SOCK_STREAM)
    s.setsockopt(SOL_SOCKET, SO_REUSEADDR, 1)
    conn = SSL.Connection(ctx, s)
    conn.connect((server, NETTEST_PORT))
    print 'Cipher =', conn.get_cipher().name()
    peer = conn.get_peer_cert()
    print 'Server =', peer.get_subject().CN
    conn.send(test_message)
    print "sent the message", test_message
    test_message = conn.recv(1024)
    print "received the message", test_message
    conn.close()

def usage( failed_test ):
    print "Test??: ", failed_test
    print "  x [string]    - iperf or udpping", failed_test
    print "  D [number]    - Debug Level 0-5", failed_test
    print "**Nettest test"
    print "  a [string]    - Master of the Test(required)"
    print "  s [string]    - Sender( or initial sender ) of the test"
    print "  r [string]    - Receiver ( or initial receiver ) of the test"
    
    print "**Iperf options"
    print "  d [seconds]   - Delay start of test"
    print "  f [character] - format output K for kilobits, or M for megabits"
    print "  i [seconds]   - interval between periodic reports"
    print "  l [bytes]     - buffer size"
    print "  n [bytes]     - termination bytes of data"
    print "  p [number]    - port"
    print "  t [seconds]   - termination in test duration seconds"
    print "  P [number]    - number of parallel running clients"
    print "  u             - UDP Datagram iperf test"
    print "  b [number]    - UDP bandwidth to send atin bits/sec, must use -u"
    print "  w [bytes]     - TCP window size"
    print "  M [bytes]     - TCP maximum segment size"
    print "  m [bytes]     - print reported TCP MSS size"
    print "  N             - TCP no delay option"
    print "  e             - Print only cumulative total stats"

    print "**UDP ping options"
    print "  n [number]    - number of rtt test"
    print "  p [number]    - port"


def main():
    isIperf    = 0
    test       = ""
    t_params   = ""
    t_master   = ""
    t_sender   = ""
    t_receiver = ""
    debug_level= "0"
    try:
        opts, args = getopt.getopt(sys.argv[1:], 'x:D:a:s:r:n:p:d:f:i:l:t:P:b:w:M:m:uNe')
    except getopt.error:
        usage(sys.argv[0])
        sys.exit(1)

    for o, a in opts:
        if o == '-x':
            test = a

        if o == '-D':
            if ((a > '0') & (a < '6')):
                debugLevel = a
	    else:
		sys.exit(1)

        if o == '-a':
            t_master = a
        if o == '-s':
            t_sender = a
        if o == '-r':
            t_receiver = a
        #iperf and udpping
        if o == '-n':
            t_params =  t_params + "-n " + a
        if o == '-p':
            t_params =  t_params + "-p " + a 
        #iperf
        if o == '-d':
            t_params =  t_params + "-d " + a
            isIperf = 1
        if o == '-f':
            t_params =  t_params + "-f " + a
            isIperf = 1
        if o == '-i':
            t_params =  t_params + "-i " + a
            isIperf = 1      
        if o == '-l':
            t_params =  t_params + "-l " + a
            isIperf = 1
        if o == '-t':
            t_params =  t_params + "-t " + a
            isIperf = 1    
        if o == '-P':
            t_params =  t_params + "-P " + a
            isIperf = 1
        if o == '-b':
            t_params =  t_params + "-b " + a
            isIperf = 1
        if o == '-w':
            t_params =  t_params + "-w " + a 
            isIperf = 1
        if o == '-M':
            t_params =  t_params + "-M " + a
            isIperf = 1
        if o == '-m':
            t_params =  t_params + "-m " + a
            isIperf = 1
        if o == '-u':
            t_params =  t_params + "-u "
            isIperf = 1
        if o == '-N':
            t_params =  t_params + "-N "
            isIperf = 1
        if o == '-e':
            t_params =  t_params + "-e "
            isIperf = 1


    if test == "udpping":
       if isIperf == 1:
            print "WRONG PING OPTIONS"
            usage( test )
            sys.exit(1)
            
    if test != "iperf":
        if test != "udpping":
            usage( test )
            sys.exit(1);

    test = debug_level + DELIM + test + DELIM + t_master + DELIM + t_sender + DELIM + t_receiver + DELIM + t_params

    if t_master=="":
        print "**ERROR: Missing the Master?"
        sys.exit(1);
    if t_sender=="":
        print "**ERROR: Missing the Sender?"
        sys.exit(1);
    if t_receiver=="":
        print "**ERROR: Missing the Receiver?"
        sys.exit(1);
        
    if test!="":
        print "test: ", test
        client_send_test(t_master, test)
    else:
        print "**FAILED:", test
        usage(test)

if __name__ == '__main__':
    main()
