/*
 *  Copyright (c) 2000 Regents of the University of California.
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  1. Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. All advertising materials mentioning features or use of this software
 *     must display the following acknowledgment:
 *       This product includes software developed by the Imaging and
 *       Distributed Collaboratories Group at Lawrence Berkeley
 *       National Laboratory.
 *  4. Neither the name of the University nor of the Laboratory may be used
 *     to endorse or promote products derived from this software without
 *     specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 *  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *  ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 *  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 *  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 *  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 *  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 *  SUCH DAMAGE.
 *
 */



/* -*-C++-*- */
#ifndef _NETLOGGER_H_
#define _NETLOGGER_H_

#include <string>
#include "logging.h"

class NetLogger
{
 public:
  
/* constructor */ 
    NetLogger();

/* Open handle for output.
 *
 * Flags for NetLoggerOpen:
 *    NL_ENV    - Check environment variable for log dest.
 *    NL_MEM    - Buffer to memory
 *    NL_APPEND - Append to file instead of overwrite
 */
    /* open by url. formats: 
     *   file://<filename> (local file)
     *   x-netlog://<host>:<port> (netlogd)
     *   x-syslog:// (syslog)
     */
    void open(const std::string& progName, const std::string& url, int flags);
    /* open by file descriptor */
    void open(const std::string& progName, int fd, int flags );

/* Set the logging level. Level 0, the default, means "write all".
 * If !=0, write()s with a level that is greater than this level 
 * will return immediately.
 */
    void setLevel(int lvl);

/* Write a NetLogger message */   
    void write(const std::string& keyword, const std::string& mesg);
    
/* Write a NetLogger message with user-provided timestamp */
    void write(const std::string& keyword, const std::string& mesg, 
	       long sec, long usec);
/* Write a NetLogger message of a certain 'level' */   
    void write(int lvl, const std::string& keyword, const std::string& mesg);
    
/* Write a NetLogger message of a certain 'level' 
 * with user-provided timestamp */
    void write(int lvl, const std::string& keyword, const std::string& mesg, 
	       long sec, long usec);

    
/* Flush memory-buffered messages 
 * Return: 1=something was flushed; 0=no msgs flushed
 */
    int flush();
    
/* Set a 'tag' to be added to every message
 * in every instance of NetLogger
 * (convenience fn)
 */
    void setTag( const std::string& tag );

/* Flush buffer, close socket/file/syslog */
    void close();

  private:
    NLhandle* mHandle_p; // Handle used in calls to C API
};

#endif  //  _NETLOGGER_H_
