/* -*-C++-*- */
/*
 *  Copyright (c) 1999 Regents of the University of California.
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  1. Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. All advertising materials mentioning features or use of this software
 *     must display the following acknowledgment:
 *       This product includes software developed by the Imaging and
 *       Distributed Collaboratories Group at Lawrence Berkeley
 *       National Laboratory.
 *  4. Neither the name of the University nor of the Laboratory may be used
 *     to endorse or promote products derived from this software without
 *     specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 *  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *  ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 *  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 *  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 *  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 *  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 *  SUCH DAMAGE.
 */

#include <iostream>
#include <cstdlib>
#include "SecurityInfo.h"
#include <cassert>
#include <cstring>
#include <string>
#ifndef WIN32
#include <sys/time.h>
#else
#include <time.h>
#include <sys/timeb.h>
#endif

using std::string;
using std::pair;
using std::cout;
using std::endl;
using std::cerr;


// Destructor:  Free the memory in the hashtable.  Only the values
// need to be deallocated, the keys are const pointers.
SecurityInfo::~SecurityInfo() {
  std::map<const char*, char*>::iterator i;
  for(i= htable.begin(); i!=htable.end(); i++) {
    delete [] (*i).second;
  }
}

int SecurityInfo::setData(const char* DN, const char* masterSecret) {
  assert(DN != 0);
  assert(masterSecret != 0);
  long timeSec;
  #ifndef WIN32
  struct timeval t;
  struct timezone tz;
  #else
  struct _timeb t;
  #endif
  #ifndef WIN32
  if(gettimeofday(&t, &tz) == -1) {
    return 0;
  }
  timeSec = t.tv_sec;
  #else
  _ftime(&t);
  timeSec = t.time;
  #endif
  char* timeString = l64a(timeSec);
  char* secret = new char[strlen(masterSecret)+strlen(timeString)+2];
  secret[0] = '\0';
  strcat(secret, masterSecret);
  strcat(secret, "#");
  strcat(secret, timeString);
  EVP_MD* sha1_md = EVP_sha1();
  unsigned char * tmp = new unsigned char[sha1_md->md_size];
  EVP_DigestInit(&ctx, sha1_md);
  EVP_DigestUpdate(&ctx, (unsigned char *) DN, strlen(DN));
  EVP_DigestFinal(&ctx, tmp, NULL);
  char printbuf[16];
  string key;
  for(int i=0; i < sha1_md->md_size; i++) {
    sprintf(printbuf,"%02X",tmp[i]);
    key += printbuf;
  }
  const char* hashedDN =strdup(key.c_str());
  htable[hashedDN] = secret;
if(htable.find(hashedDN) == htable.end())
  cout << "couldn't find it!!!" << endl;
else
  delete[] tmp;
  return 1;
}

bool SecurityInfo::checkAccess(const char* secData, const char* command) {
  assert(secData != 0);
  assert(command != 0);
  char* sInfo = strdup(secData);
  char* tokenPtr = strtok(sInfo, ":*:"); 
  if(tokenPtr == NULL) {
    cerr << "unable to tokenize secData" << endl;
    return 0;
  }
  if(htable.find(tokenPtr) == htable.end()) {
    cerr << "unable to find an entry in the hash table" << endl;
    return 0;
  }
  char* secretAndTimeTmp = htable[tokenPtr];
  tokenPtr = strtok(NULL, ":*:");
  if(tokenPtr == NULL) {
    cerr << "couldn't get the second token" << endl;
    return 0;
  }
  char* secretAndTime = strdup(secretAndTimeTmp);
  char* tokenPtr2 = strtok(secretAndTime, "#");
  char* secret;
  if(tokenPtr2 == NULL) {
    cerr << "unable to parse the time" << endl;
    return 0;
  }
  secret = strdup(tokenPtr2);
  tokenPtr2 = strtok(NULL, "#");
  if(tokenPtr2 != NULL) {
    long timeSecOld = a64l(tokenPtr2);
    long timeSec;
    #ifndef WIN32
    struct timeval t;
    struct timezone tz;
    #else
    struct _timeb t;
    #endif
    #ifndef WIN32
    if(gettimeofday(&t, &tz) == -1) {
      return 0;
    }
    timeSec = t.tv_sec;
    #else
    _ftime(&t);
    timeSec = t.time;
    #endif
    if(timeSec - timeSecOld > 3660) {
cout << "time has expired" << endl;
      return 0; 
    }
  }else {
cout << "tokenPtr2 was null" << endl;
    return 0;
  }
  char* tmp2 = new char[strlen(command) + strlen(secret) +1];
  tmp2[0] = '\0';
  strcat(tmp2, command);
  strcat(tmp2, secret);
  char* tmp = new char[129]; 
  strncpy(tmp, tmp2, 127);
  tmp[127] = '\0'; 
  delete[] tmp2;
  EVP_MD* sha1_md = EVP_sha1();
  unsigned char* hash = new unsigned char[sha1_md->md_size];
  EVP_MD_CTX ctx2;
  EVP_DigestInit(&ctx2, sha1_md); 
  EVP_DigestUpdate(&ctx2, (unsigned char *) tmp, strlen(tmp));
  EVP_DigestFinal(&ctx2, hash, NULL);
  char printbuf[16];
  string str;
  for(int i=0; i < sha1_md->md_size; i++) {
    sprintf(printbuf, "%02X", hash[i]);
    str += printbuf;  
  }
  delete[] hash;   
  delete[] tmp;
  free(sInfo);
  free(secret);
  free(secretAndTime);
  return 1;
}

