/* -*-C++-*- */
/*
 *  Copyright (c) 1999 Regents of the University of California.
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  1. Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. All advertising materials mentioning features or use of this software
 *     must display the following acknowledgment:
 *       This product includes software developed by the Imaging and
 *       Distributed Collaboratories Group at Lawrence Berkeley
 *       National Laboratory.
 *  4. Neither the name of the University nor of the Laboratory may be used
 *     to endorse or promote products derived from this software without
 *     specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 *  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *  ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 *  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 *  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 *  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 *  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 *  SUCH DAMAGE.
 *
 */

#include "SimpleACLAuthorizer.h"
#include <fstream>
#include <iostream>  // for testing
#include <cstring> // for strncpy

using std::string;
using std::pair;
using std::ifstream;

SimpleACLAuthorizer::SimpleACLAuthorizer(const string& file)
{
    readACLFile(file.c_str());
}

SimpleACLAuthorizer::SimpleACLAuthorizer(const char* file)
{
    readACLFile(file);
}

SimpleACLAuthorizer::~SimpleACLAuthorizer( void )
{
}

bool
SimpleACLAuthorizer::authorize(const string& name, const string& rqstAct)
{
    string newName, newRqstAct;
    removeWS(name, newName);
    removeWS(rqstAct, newRqstAct);

    strStrMap::iterator itr = aclMap.find(newName);
    if (itr == aclMap.end())
    { // didn't find it
	return false;
    }
    return checkAction(newRqstAct, itr->second);
}

bool 
SimpleACLAuthorizer::authorize(const char* name, const char* rqstAct)
{
    return authorize(string(name), string(rqstAct));
}

void 
SimpleACLAuthorizer::authorize(const string& name, string* allwdActs)
{
    
}

void
SimpleACLAuthorizer::readACLFile(const char* file)
{
    ifstream inStrm(file);
    if (! inStrm) // Coulnd't open the file
    {
	throw string("Unable to open the ACL file");
    }
    while ( !inStrm.eof() ) 
    {
	string line("");
	std::getline(inStrm, line);
	parseLine(line);
    }
}

void
SimpleACLAuthorizer::parseLine(string& line)
{
    if (line != "")
    { // necessary since strm.eof() isn't true until one blank line has 
	// passed here.
	string dn;
	removeWS(line, dn);
	if (dn.at(0) == '#')
	{ // this was a comment line
	    return;
	}
	aclMap[dn] =  "";
    }
}

bool
SimpleACLAuthorizer::checkAction(string& rqstAct, string& actList)
{
    
    return true;
}
