/*
 *  Copyright (c) 1999 Regents of the University of California.
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  1. Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. All advertising materials mentioning features or use of this software
 *     must display the following acknowledgment:
 *       This product includes software developed by the Imaging and
 *       Distributed Collaboratories Group at Lawrence Berkeley 
 *       National Laboratory.
 *  4. Neither the name of the University nor of the Laboratory may be used
 *     to endorse or promote products derived from this software without
 *     specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 *  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *  ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 *  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 *  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 *  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 *  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 *  SUCH DAMAGE.
 *
 *  $Id: ipnet.cc,v 1.4 2001/08/30 02:05:26 boverhof Exp $
 */


#include "ipnet.h"

IPNet::IPNet(int fd, string g, int timeout, short p) : Network(fd, timeout, p), group_addr(g), ttl(10)
{
     setClassName( "IPNet" );
}

IPNet::~IPNet()
{
}


int IPNet::openSocket()
{
    sock = makeMulti();
    if (sock < 0)
	return (-1);	
    return 0;
}

int IPNet::makeMulti()
{
    printDebug(4, "makeMulti()\n");
    char val;
    long on = 1;
    struct ip_mreq mreq;
    //unsigned long addr = convertAddr(group_addr);
    unsigned long addr = convertAddr(group_addr.c_str());

    if ((sock = socket(AF_INET, SOCK_DGRAM, 0)) < 0)
    {
	printDebug(4, "Error makeMulti()");
	return (-1);
    }
    peer.sin_family = AF_INET;
    peer.sin_port = htons(port);
    memset(&(peer.sin_addr), 0, sizeof(struct in_addr));
    peer.sin_addr.s_addr = INADDR_ANY;

    if (setsockopt(sock, SOL_SOCKET, SO_REUSEADDR, (char *)&on, sizeof(on)) < 0)
    {
	printDebug(4, "IPNet:setsockopt: SO_REUSEADDR\n");
	close(sock);
	return (-1);
    }

    if (bind(sock, (struct sockaddr *)&peer, sizeof(peer)) < 0)
    {
	printDebug(4, "IPNet--bind failed\n");
	return (-1);
    }
    peer.sin_addr.s_addr = addr;

    /*
    val = 0;	// turn off loopback
    if (setsockopt(sock,IPPROTO_IP, IP_MULTICAST_LOOP,(char *)&val,sizeof(val))<0)
    {
	printDebug(4, "IPNet--setsockopt failed for IP_MULTICAST_LOOP\n");
	close(sock);
	return (-1);
    }  */ 

    val = ttl;
    if (setsockopt(sock,IPPROTO_IP,IP_MULTICAST_TTL,(char *)&val,sizeof(val)) < 0)
    {
	printDebug(4, "IPNet: setsockopt--IP_MULTICAST_TTL\n");
	close(sock);
	return (-1);
    }
    mreq.imr_multiaddr.s_addr = addr;
    mreq.imr_interface.s_addr = INADDR_ANY;
    if (setsockopt(sock,IPPROTO_IP,IP_ADD_MEMBERSHIP, (char *)&mreq,sizeof(mreq)) < 0)
    {
	printDebug(4, "IPNet--setsockopt failed for IP_ADD_MEMBERSHIP");
	close(sock);
 	return (-1);
    }
    return sock;
} 	
     		

void IPNet::setAddr(const string s)
{
    group_addr = s;	
    printDebug(4, "IPNet::setAddr: group_addr: %s\n", group_addr.c_str());
}  

void IPNet::setTTL(int t)
{
    if (t < 0)
	ttl = 0;
    else if (t > 127)
	ttl = 127;
    else
	ttl = t;
}
