/*
 *  This class is used to launch and control an iperf test.
 *  The actual iperf test will run as a separate thread.
 */
#define HEADERS()

#include <cerrno>
#include <iostream>
#include "IperfTest.hpp"
#include "IperfTestInfo.h"
#include "Results.h"
#include "headers.h"

#ifdef sun
#include <sys/systeminfo.h>
#endif sun

using std::cerr;
using std::endl;
using std::string;

/* -------------------------------------------------------------------
 * ------------------------------------------------------------------- */

IperfTest::IperfTest( IperfTestInfo *intestinfo ) 
  : Thread(), PerfSocket( intestinfo )
{
    if( mSettings_p->getRemoteTestPeer() == "" )
	cerr << "Iperf test peer is not set" << endl;
    mRemoteHost = mSettings_p->getRemoteTestPeer();
    mServer = mSettings_p->isSender();
    getLocalname( &mLocalHost );
}

/* -------------------------------------------------------------------
 * ------------------------------------------------------------------- */

IperfTest::IperfTest( IperfTestInfo *intestinfo, Results* r_ptr ) 
  : Thread(), PerfSocket( intestinfo )
{
    rContainer = r_ptr;

    if( mSettings_p->getRemoteTestPeer() == "" )
	cerr << "Iperf test peer is not set" << endl;
    mRemoteHost = mSettings_p->getRemoteTestPeer();
    mServer = mSettings_p->isSender();
    getLocalname( &mLocalHost );
}

/* -------------------------------------------------------------------
 * ------------------------------------------------------------------- */
IperfTest::~IperfTest()
{
   rContainer = NULL;
   delete rContainer;
}

/* -------------------------------------------------------------------
 * ------------------------------------------------------------------- */
void IperfTest::Run( void )
{    
    if( !mServer )
      {
	// connect
	sleep( 5 );
	Connect( mRemoteHost.c_str(), mLocalHost.c_str() );
      }
    else
      {
	// listen for a connection and accept it
	Listen( mLocalHost.c_str() );
	if( !(mSettings_p->getUDPFlag() ))
	    {
	    mTsock = Accept();
	    // check that this is the expected test partner
	    // close the listen socket
	    Close();
	    SetSocket( mTsock );
	    }
      }
    //byte_printf( getsock_tcp_windowsize( mSock ), 'A' );

    // set the printout interval
    mSettings_p->setReportInterval( 20.0 );

    if( !mServer )
        {
	// send data
	if ( mSettings_p->getUDPFlag() ) 
	    Send_UDP();
	else
	    Send_TCP();
	}
    else
        {
	if ( mSettings_p->getUDPFlag() ) 
	    Recv_UDP();
	else 
	    Recv_TCP();

        }
}

/* -------------------------------------------------------------------
 * get the name of the local host and return it
 * in the character buffer passed in.
 *
 * ------------------------------------------------------------------- */

void IperfTest::getLocalname(string *host)
{
    char buf[256];
#ifdef sun 
    sysinfo(SI_HOSTNAME, buf, (long)256);
    struct hostent *hp = gethostbyname(buf);
    if (hp)
	*host = hp->h_name;
#else
    gethostname(buf,256);
    *host = buf;
#endif  
}


/* -------------------------------------------------------------------
 * begin()
 * ------------------------------------------------------------------- */

void IperfTest::begin( void )
{
   char   lHost[MAXHOSTLEN];
   char   rHost[MAXHOSTLEN];

   strcpy(lHost, mLocalHost.c_str());
   strcpy(rHost, mRemoteHost.c_str());

   setResults(rContainer, lHost, rHost);
   Start();
}

/* -------------------------------------------------------------------
 * endTest()
 * ------------------------------------------------------------------- */

void IperfTest::endTest( void )
{
   Join();
   //unsetResults();
}


