/* -*-C++-*- */
/*
 *  Defines the variables for a TCP test
 */

#ifndef IPERFTESTINFO_H
#define IPERFTESTINFO_H

#include "TestInfo.h"
#include <string>
#include <sys/types.h>

using std::ostream;
using std::string;

class IperfTestInfo : public TestInfo
{
   public:

    IperfTestInfo(void);
    IperfTestInfo( const TestInfo& curinfo );
    virtual ~IperfTestInfo(void);

    virtual void setUserParams( void );

    // Setting Member functions
    inline void setTCP_MSS( int mss )
    {
	mMaxSegSize = mss;
    };
    inline void setTCPWindowSize( int winSize )
    {
	mWinSize = winSize;
    };
    inline void setTCP_Nodelay( bool isDelay )
    {
	mIsNoDelay = isDelay;
    };
    inline void setMcastTTL( int ttl )
    {
	mMcastTtl = ttl;
    };
    inline void setUDPRate( double rate )
    {
	mUdpRate = rate;
    };
    inline void setMcastAddr( const string& addr )
    {
	mMcastAddr = addr;
    };
    inline void setPrintMSS( bool print )
    {
	mPrintMSS = print;
    };
    inline void setUDPFlag( bool isUDP )
    {
	mIsUdp = isUDP;
    };
    inline void setClientThreads( int num )
    {
	mThreads = num;
    };
    inline void setTOS( int tos )
    { 
	mTOS = tos; 
    };
    inline void setFormat( char fm )
    { 
	mFormat = fm; 
    };
    inline void setGroupID( pthread_t gID )
    { 
	groupID = gID; 
    };

    // Retriving Member Functions
    inline int getClientThreads( void ) const
    {
	return mThreads;
    }
    inline int getTCP_MSS(void) const 
    { 
	return mMaxSegSize; 
    };
    inline int getTCPWindowSize(void) const 
    { 
	return mWinSize; 
    };
    inline bool getUDPFlag(void) const 
    { 
	return mIsUdp; 
    };
    inline bool getTCP_Nodelay(void) const 
    { 
	return mIsNoDelay; 
    };
    inline int getMcastTTL(void) const 
    { 
	return mMcastTtl; 
    };
    inline double getUDPRate(void) const 
    { 
	return mUdpRate; 
    };
    inline const string& getMcastAddr(void) const 
    { 
	return mMcastAddr; 
    };
    inline int getTOS(void) const 
    { 
	return mTOS; 
    };
    inline char getFormat(void) const 
    { 
	return mFormat; 
    };
    inline bool getPrintMSS(void) const 
    { 
	return mPrintMSS; 
    };
    inline pthread_t getGroupID(void) const
    { 
	return groupID; 
    };
    virtual ostream & printVariables(ostream &); // Dump the variables

   private:

        double mUdpRate;  // -b rate at which to send test packets
	double mAmount;   // -n,-t
	double mInterval; // -i   

        int mWinSize;      // TCP Window size
        int mMaxSegSize;   // maximum segment size
        int mMcastTtl;     // time-to-live to set in packets
	int mThreads;	   // Client Threads
        string mMcastAddr;  // multicast address to use for test

	char  mFormat;  // K or M, kilobits or megabits
	int   mTOS;     // Type of Service
	//u_char mTTL;	// --ttl

	bool  mIsUdp;     // Whether it is tcp or udp test
	bool  mPrintMSS;  // boolean generated by specifying the -M flag
        bool mIsNoDelay;  // Bool

        pthread_t groupID;
};

#endif /* IPERFTESTINFO_H */
