/* -*-C++-*- */
/*
 *  Copyright (c) 1999 Regents of the University of California.
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  1. Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. All advertising materials mentioning features or use of this software
 *     must display the following acknowledgment:
 *       This product includes software developed by the Imaging and
 *       Distributed Collaboratories Group at Lawrence Berkeley
 *       National Laboratory.
 *  4. Neither the name of the University nor of the Laboratory may be used
 *     to endorse or promote products derived from this software without
 *     specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 *  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *  ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 *  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 *  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 *  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 *  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 *  SUCH DAMAGE.
 *
 */

/* ---------------------------------------------------------
 *   CoordInfo holds all the information about the current
 *   test.
 * --------------------------------------------------------- */


#include "CoordInfo.h"

using std::cout;
using std::endl;

CoordInfo::CoordInfo()
    : mIsTestRequester(false), mIsTestMaster(false), mIsTestSender(false),
      mIsTestReceiver(false), mCoordTestHost(""), mKeyfilename(""), mCertfilename("")
{
}

CoordInfo::CoordInfo(const bool isRequester, const string localName)
    : mIsTestRequester(isRequester), mIsTestMaster(false), mIsTestSender(false),
      mIsTestReceiver(false), mLocalHost(localName)
{
}

CoordInfo::CoordInfo( const CoordInfo& cInfo )
   : mIsTestRequester(cInfo.mIsTestRequester), mLocalHost(cInfo.mLocalHost)
{
    mIsTestMaster    = cInfo.mIsTestMaster;
    mIsTestSender    = cInfo.mIsTestSender;
    mIsTestReceiver  = cInfo.mIsTestReceiver;

    mRequesterName   = cInfo.mRequesterName;
    mMasterName	     = cInfo.mMasterName;
    mCoordTestHost   = cInfo.mCoordTestHost;

    mTestSender      = cInfo.mTestSender;
    mTestReceiver    = cInfo.mTestReceiver;
    mTestName        = cInfo.mTestName;
    mIsSOTest        = cInfo.mIsSOTest;

    mIperfParams     = cInfo.mIperfParams;
    mPingParams      = cInfo.mPingParams;
    mMultiParams     = cInfo.mMultiParams;
    mTunedParams     = cInfo.mTunedParams;
    mTraceParams     = cInfo.mTraceParams;

    mKeyfilename     = cInfo.mKeyfilename;
    mCertfilename    = cInfo.mCertfilename;

    results_p 	     = cInfo.results_p;
}

CoordInfo::~CoordInfo(void)
{
   results_p = NULL;
}

void
CoordInfo::printVariables( void )
{
    cout << "\tmIsTestRequester  : " << mIsTestRequester << endl; 
    cout << "\tmIsTestMaster     : " << mIsTestMaster    << endl; 
    cout << "\tmIsTestSender     : " << mIsTestSender    << endl; 
    cout << "\tmIsTestReceiver   : " << mIsTestReceiver    << endl;
    cout << "\tmIsSOTest         : " << mIsSOTest        << endl;
    cout << "\tmCoordTestHost    : " << mCoordTestHost   << endl;

    cout << "\tmRequesterName    : " << mRequesterName   << endl;
    cout << "\tmMasterName       : " << mMasterName      << endl;
    cout << "\tmLocalHost        : " << mLocalHost       << endl;

    cout << "\tmTestSender       : " << mTestSender      << endl;
    cout << "\tmTestReceiver     : " << mTestReceiver      << endl;

    cout << "\tmTestName         : " << mTestName        << endl;
    cout << "\tmIperfParams      : " << mIperfParams      << endl;
    cout << "\tmPingParams       : " << mPingParams      << endl;
    cout << "\tmMultiParams      : " << mMultiParams      << endl;
    cout << "\tmTunedParams      : " << mTunedParams      << endl;
    cout << "\tmTraceParams      : " << mTraceParams      << endl;

    cout << "\tmKeyfilename      : " << mKeyfilename     << endl;
    cout << "\tmCertfilename     : " << mCertfilename    << endl;
    cout << "\tresults_p         : " << results_p        << endl;

}
/*
CoordInfo& 
CoordInfo::operator=( const CoordInfo& cInfo )
{
    mIsTestRequester = cInfo.mIsTestRequester;
    mIsTestMaster    = cInfo.mIsTestMaster;
    mIsTestSender    = cInfo.mIsTestSender;
    mIsTestReceiver  = cInfo.mIsTestReceiver;

    mRequesterName   = cInfo.mRequesterName;
    mMasterName	     = cInfo.mMasterName;
    mCoordTestHost   = cInfo.mCoordTestHost;
    mLocalHost       = cInfo.mLocalHost;

    mTestSender      = cInfo.mTestSender;
    mTestReceiver    = cInfo.mTestReceiver;
    mTestName        = cInfo.mTestName;

    mIperfParams     = cInfo.mIperfParams;
    mPingParams      = cInfo.mPingParams;
    mMultiParams     = cInfo.mMultiParams;
    mTunedParams     = cInfo.mTunedParams;

    mKeyfilename     = cInfo.mKeyfilename;
    mCertfilename    = cInfo.mCertfilename;

    results_p 	     = cInfo.results_p;

    return *this;
}
*/
