/* -*-C++-*- */
/* Copyright (c) 1999 Regents of the University of California.
 * rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgment:
 *       This product includes software developed by the Imaging and
 *       Distributed Collaboratories Group at Lawrence Berkeley
 *       National Laboratory.
 * 4. Neither the name of the University nor of the Laboratory may be used
 *    to endorse or promote products derived from this software without
 *    specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */


#ifndef DISPLAYGUI_H
#define DISPLAYGUI_H

#include <iostream>
#include <string>
#include <map>

using std::string;
using std::cout;
using std::cin;
using std::map;

static const string REPORTS( "reports" );
static const string MASTER( "master" );
static const string IPERF( "iperf" );
static const string UDPPING( "udpping" );
static const string MULTIPING( "multiping" );
static const string TUNEDTCP( "tuned" );
static const string DEBUG( "debug" );

static const string TRACEROUTE( "traceroute" );
static const string PCHAR( "pchar" );
static const string PATHCHAR( "pathchar" );
static const string PIPECHAR( "pipechar" );
static const string QUIT( "quit" );

static const string EMPTY("X");
//const string START("START");
static const string FAILED("FAILED");
static const string FINISHED("FINISHED");
static const string DELIM( "/" );

static const string IPERF_PORT("25567");
static const string UDPPING_PORT("3642");
static const string MULTIPING_ADDR("224.35.36.37");

typedef map < char, string > TM;
typedef map < char, string >::iterator TMi;

class Results;
class CoordInfo;

class DisplayFunc {

  private:
    const  static int NUM = 11;
    char   abbr[11];
    TM     tests_Map;
    TMi    pos;

    inline int isContinue()
    {
    	string contin;
    	getline( cin, contin );
    	if( (contin!="") && ((contin[0]=='Y') || (contin[0]=='y')) )
           return 1;
    	return -1;
    };

  public:
    DisplayFunc();
    ~DisplayFunc();

    void    displayUseage();
    string  displayAskUser();
    void    displayChangedReportResults( Results* );
    void    displayGetAcceptHost(  const string masterName, string& ahost );
    void    displayGetTestHosts( void );

    int     getUseDefaults( const string, const string );
    int     getUseDefaults_SO( const string, const string );
    void    getMaster( string& );
    void    getTestHosts( CoordInfo& );
    void    changeDebugLevel( string& );

    void    displayAskUserIperf( void );
    void    displayResult( const string message, const string answer );

    void    displayAcceptHost( const string ahost );
    void    displayCurrentTest( const string params );
    void    displayCurrentTest_SO( const string params );

    void    askUserIperf( string& ctest );
    void    askUserPing( string& ctest );
    int     askUserMulti( string& ctest );
    void    askUserTunedTcp( string& ctest );
    void    askUserTrace( string& ctest );

    void    getMultiOptions( string&, string&, string& );
    void    getPingOptions( string& amount, string& port );

    string  prompt_for_Input( const string prompt );
    void    askQuestion( const string param, string& ans );
    int     askQuestion( const string param );
    int     askContinue( void );
    void    getFirstWord( string& ans );

    inline void    display_Message( const string message )
    {
        cout << message;
    };

    inline void getAnswer( string& ans )
    {
    	getline( cin, ans );
    };
};
#endif //DISPLAYGUI_H
